@@ -7,6 +7,8 @@ def create_date_df(startDate = '20200101', endDate = '20210101'):
   date_list = [datetime.strftime(x, '%Y-%m-%d') for x in list(pd.date_range(start = startDate, end= endDate))]
   date_pd = pd.DataFrame(date_list)
   date_pd.rename(columns={0:'DATE'}, inplace= True)
+  date_pd = date_pd.sort_values(by='DATE')
+  date_pd['DATE'] = pd.to_datetime(date_pd['DATE'], infer_datetime_format=True)
   return date_pd
 
 def sg_holiday_feature(holiday_df, startDate = '20200101', endDate = '20210101'):
